﻿namespace AbleCommerce.Layouts.Fixed
{
    using Code;
    using System;
    using System.Text;
    using System.Web;
    using System.Web.Security;
    using System.Web.UI;
    using System.Web.UI.WebControls;
    public partial class Base : System.Web.UI.MasterPage
    {
	    private const string AntiXsrfTokenKey = "__AntiXsrfToken";
        private string _antiXsrfTokenValue;

        protected void Page_Init(object sender, EventArgs e)
        {
	        // The code below helps to protect against XSRF attacks
            var requestCookie = Request.Cookies[AntiXsrfTokenKey];
            Guid requestCookieGuidValue;
            if (requestCookie != null && Guid.TryParse(requestCookie.Value, out requestCookieGuidValue))
            {
                // Use the Anti-XSRF token from the cookie
                _antiXsrfTokenValue = requestCookie.Value;
                Page.ViewStateUserKey = _antiXsrfTokenValue;
            }
            else
            {
                // Generate a new Anti-XSRF token and save to the cookie
                _antiXsrfTokenValue = Guid.NewGuid().ToString("N");
                Page.ViewStateUserKey = _antiXsrfTokenValue;

                var responseCookie = new HttpCookie(AntiXsrfTokenKey)
                {
                    HttpOnly = true,
                    Value = _antiXsrfTokenValue
                };
                if (FormsAuthentication.RequireSSL && Request.IsSecureConnection)
                {
                    responseCookie.Secure = true;
                }
                Response.Cookies.Set(responseCookie);
            }

            Page.PreLoad += new EventHandler(Master_Page_PreLoad);

            if (head1 != null)
            {
                // insert necessary javascripts
                string scriptTag = "<script src=\"{0}\" type=\"text/javascript\"></script>";
                string jquery = Page.ResolveUrl("~/Scripts/jquery-1.10.2.min.js");
                string jqueryUI = Page.ResolveUrl("~/Scripts/jquery-ui.min.js");
                string equalHeightsUrl = Page.ResolveUrl("~/Scripts/jquery.equalheights.js");
                head1.Controls.Add(new LiteralControl(string.Format(scriptTag, jquery)));
                head1.Controls.Add(new LiteralControl(string.Format(scriptTag, jqueryUI)));
                head1.Controls.Add(new LiteralControl(string.Format(scriptTag, equalHeightsUrl)));
                
                if (AbleCommerce.Code.PageHelper.IsResponsiveTheme(this.Page))
                {
                    string footable = Page.ResolveUrl("~/Scripts/footable.js");
                    string bootstrap = Page.ResolveUrl("~/Scripts/bootstrap.min.js");
                    head1.Controls.Add(new LiteralControl(string.Format(scriptTag, footable)));
                    head1.Controls.Add(new LiteralControl(string.Format(scriptTag, bootstrap)));
                }
            }
        }

	    protected void Master_Page_PreLoad(object sender, EventArgs e)
        {
            HiddenField AntiXsrfToken = PageHelper.RecursiveFindControl(Page, "AntiXsrfToken") as HiddenField;
            if (AntiXsrfToken == null)
            {
                throw new InvalidOperationException("Validation of Anti-XSRF token failed.");
            }
            
            if (!IsPostBack)
            {
                #pragma warning disable 612, 618
                string encodedTokenValue = MachineKey.Encode(Encoding.UTF8.GetBytes(Page.ViewStateUserKey), MachineKeyProtection.All);
                #pragma warning restore 612, 618

                // Set Anti-XSRF token
                AntiXsrfToken.Value = encodedTokenValue;
            }
            else
            {
                #pragma warning disable 612, 618
                string decodedToeknValue = Encoding.UTF8.GetString(MachineKey.Decode(AntiXsrfToken.Value, MachineKeyProtection.All));
                #pragma warning restore 612, 618

                // Validate the Anti-XSRF token
                if (decodedToeknValue != _antiXsrfTokenValue)
                {
                    throw new InvalidOperationException("Validation of Anti-XSRF token failed.");
                }
            }
        }
    }
}